@@ -912,6 +912,10 @@ class MulticlassDatasets(Datasets):
         data.target = data.target\
             .apply(lambda x: x.replace('class', ''))\
             .astype(int)
+
+        mask = (data.iloc[:, :-1].nunique() > 10).tolist()
+        mask.append(True)
+        data = data.loc[:, mask].copy()
         return data
 
     def fetch_autouniv_au4(self):
@@ -938,13 +942,13 @@ class MulticlassDatasets(Datasets):
         data = pd.read_csv(FETCH_URLS['mice_protein'])
         data.rename(columns={'class': 'target'}, inplace=True)
         data.drop(columns=['MouseID'], inplace=True)
+        data.replace('?', np.nan, inplace=True)
 
         mask = (data.iloc[:, :-1].nunique() > 10).tolist()
         mask.append(True)
         mask2 = data.isna().sum() < 10
-
         data = data.loc[:, mask & mask2].dropna().copy()
-        data.replace('?', np.nan, inplace=True)
+
         data.iloc[:, :-1] = data.iloc[:, :-1].astype(float)
 
         mapper = {v: k for k, v in enumerate(data.target.unique())}
@@ -1128,9 +1132,10 @@ class MulticlassDatasets(Datasets):
 
         https://www.openml.org/d/185
         """
-        data = pd.read_csv(FETCH_URLS['baseball'])
+        data = pd.read_csv(FETCH_URLS['baseball'], na_values='?')
         data.drop(columns=['Player', 'Position'], inplace=True)
         data.rename(columns={'Hall_of_Fame': 'target'}, inplace=True)
+        data.dropna(inplace=True)
         return data
 
 
